@@ -239,7 +239,7 @@ def _PyScons(env, target, source, scons, execute=None, options="-Q", sig_options
     cmd = "scons %s %s -f%s %s" % (options, sig_options, scons, args)
     cleancmd = cmd + " --clean"
 
-    env.Execute(Mkdir(basename))
+    if not os.path.exists(basename): env.Execute(Mkdir(basename))
     exe = os.path.join(basename, "EXECUTE")
     file = open(exe, 'w')
     print >>file, "#!/bin/bash"
@@ -327,10 +327,10 @@ def PySconsSetup(env=None, args=ARGUMENTS, tools=['default', PYTOOL()]):
         shutil.mv(force, out)
         env.Exit(0)
 
-    env.Command(ship, sources, "tar cjf $TARGET $SOURCES")
+    env.Command(ship, sources + [exe], "tar cjf $TARGET $SOURCES")
     env.Default(targets)
     SIGNATURES = os.path.join(basename, ".sconsign.dblite")
-    env.Command(out, targets + [exe], "tar cjf $TARGET $SOURCES")
+    env.Command(out, targets, "tar cjf $TARGET $SOURCES")
 
     return targets, sources, basename
 
